@@ -503,6 +503,10 @@ class TestApp(object):
             if isinstance(value, forms.File):
                 if value.value:
                     _append_file([key] + list(value.value))
+                else:
+                    # If no file was uploaded simulate an empty file with no
+                    # name like real browsers do:
+                    _append_file([key, b'', b''])
             elif isinstance(value, forms.Upload):
                 file_info = [key, value.filename]
                 if value.content is not None:
@@ -618,7 +622,7 @@ class TestApp(object):
         res.app = app
         res.test_app = self
 
-        # We do this to make sure the app_iter is exausted:
+        # We do this to make sure the app_iter is exhausted:
         try:
             res.body
         except TypeError:  # pragma: no cover
